==> claromentis-framework-9.6.6-26891208.zip: web/intranet/core/classes/Twig/TwigRenderListener.php <==
<?php
namespace Claromentis\Core\Twig;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"] = (@$GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"] ?: array()) + array("_00b7858db26" . "a1c1cadb1466" . "f573d5d80" => base64_decode("Y29tbW9uL2xh" . "eW91dHMvYmFz" . "ZV90d2lnX2h5" . "YnJpZC5odG1s"), "_4c05b95d6bb1191967" . "ccfe58bffbbd86" => base64_decode("b25LZXJ" . "uZWxWaW" . "V3"), "_6d3a1bbb0c16f" . "ad009bf87b1580" . "2998e" => base64_decode("dHdpZy50ZW1wbGF" . "0ZQ=="), "_75ca9d21af5efc8ea1044388098af" . "784" => base64_decode("dHdpZy5hcmd" . "1bWVudHM="));
use Claromentis\Core\Event\EventSubscriberInterface;
use Claromentis\Core\Http\TemplaterCallResponse;
use Claromentis\Core\Http\TwigResponse;
use Claromentis\Core\Http\TwigTemplaterResponse;
use Claromentis\Core\Twig\Events\TwigPreRenderEvent;
use Symfony\Component\EventDispatcher\EventDispatcherInterface;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Event\GetResponseForControllerResultEvent;
use Symfony\Component\HttpKernel\KernelEvents;
use Twig;









class TwigRenderListener implements EventSubscriberInterface
{
    
    
    
    
    protected $twig;
    
    
    
    
    protected $dispatcher;
    
    
    
    
    
    
    
    public function __construct(Twig\Environment $_6b67522fca36b32553cd09de29b97ff8, EventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        $this->twig = $_6b67522fca36b32553cd09de29b97ff8;
        $this->dispatcher = $_b497ce6f2af10f67516aed0ecf34d8cf;
    }
    public static function getSubscribedEvents()
    {
        return [KernelEvents::VIEW => [$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_4c05b95d6bb11919" . "67ccfe58bffbbd86"], -4]];
    }
    
    
    
    
    
    
    
    
    
    
    
    public function onKernelView(GetResponseForControllerResultEvent $event)
    {
        $_fd5a3a643834299cbdadfc3540ba0bcb = $event->getControllerResult();
        
        
        if (!$_fd5a3a643834299cbdadfc3540ba0bcb instanceof TwigResponse) {
            return;
        }
        
        
        $this->dispatchPreRenderEvent($_fd5a3a643834299cbdadfc3540ba0bcb);
        
        
        $this->updateControllerResultEvent($event, $_fd5a3a643834299cbdadfc3540ba0bcb);
    }
    
    
    
    
    
    
    
    
    protected function dispatchPreRenderEvent(TwigResponse $_fd5a3a643834299cbdadfc3540ba0bcb)
    {
        $event = new TwigPreRenderEvent($_fd5a3a643834299cbdadfc3540ba0bcb->getTemplate(), $_fd5a3a643834299cbdadfc3540ba0bcb->getArguments());
        $this->dispatcher->dispatch(TwigEvents::PRE_RENDER, $event);
        $_fd5a3a643834299cbdadfc3540ba0bcb->setTemplate($event->getTemplate());
        $_fd5a3a643834299cbdadfc3540ba0bcb->setArguments($event->getArguments());
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    protected function updateControllerResultEvent(GetResponseForControllerResultEvent $event, TwigResponse $_fd5a3a643834299cbdadfc3540ba0bcb)
    {
        if ($_fd5a3a643834299cbdadfc3540ba0bcb instanceof TwigTemplaterResponse) {
            
            
            
            $_edae18fae8c53743e7224eb1325ebb6b = new TemplaterCallResponse($GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_00b7858db26a1c1cadb1466f573d5d8" . "0"], [$GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_6d3a1bbb0c16fad0" . "09bf87b15802998e"] => $_fd5a3a643834299cbdadfc3540ba0bcb->getTemplate(), $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_75ca9d21af5efc8ea1044388098a" . "f784"] => $_fd5a3a643834299cbdadfc3540ba0bcb->getArguments()], $_fd5a3a643834299cbdadfc3540ba0bcb->getPageTitle());
            $_edae18fae8c53743e7224eb1325ebb6b->http_status = $_fd5a3a643834299cbdadfc3540ba0bcb->getHttpStatus();
            $_edae18fae8c53743e7224eb1325ebb6b->http_headers = $_fd5a3a643834299cbdadfc3540ba0bcb->getHttpHeaders();
            $event->setControllerResult($_edae18fae8c53743e7224eb1325ebb6b);
        } else {
            
            
            $_fd5a3a643834299cbdadfc3540ba0bcb = new Response($this->twig->render($_fd5a3a643834299cbdadfc3540ba0bcb->getTemplate(), $_fd5a3a643834299cbdadfc3540ba0bcb->getArguments()), $_fd5a3a643834299cbdadfc3540ba0bcb->getHttpStatus(), $_fd5a3a643834299cbdadfc3540ba0bcb->getHttpHeaders());
            $event->setResponse($_fd5a3a643834299cbdadfc3540ba0bcb);
        }
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/core/classes/Twig/TwigRenderListener.php <==
<?php
namespace Claromentis\Core\Twig;

$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"] ?: array()) + array("_75ca9d21af5" . "efc8ea104438" . "8098af784" => base64_decode("dHdpZy5h" . "cmd1bWVu" . "dHM="), "_6d3a1bbb0c16fad009bf" . "87b15802998e" => base64_decode("dHdpZy50ZW1" . "wbGF0ZQ=="), "_4c05b95d6" . "bb1191967c" . "cfe58bffbb" . "d86" => base64_decode("b25LZX" . "JuZWxW" . "aWV3"), "_00b7858db26a1c1" . "cadb1466f573d5d8" . "0" => base64_decode("Y29tbW9uL2xheW91d" . "HMvYmFzZV90d2lnX2" . "h5YnJpZC5odG1s"));
use Claromentis\Core\Event\EventSubscriberInterface;
use Claromentis\Core\Http\TemplaterCallResponse;
use Claromentis\Core\Http\TwigResponse;
use Claromentis\Core\Http\TwigTemplaterResponse;
use Claromentis\Core\Twig\Events\TwigPreRenderEvent;
use Symfony\Component\EventDispatcher\EventDispatcherInterface;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Event\ViewEvent;
use Symfony\Component\HttpKernel\KernelEvents;
use Twig;









class TwigRenderListener implements EventSubscriberInterface
{
    
    
    
    
    protected $twig;
    
    
    
    
    protected $dispatcher;
    
    
    
    
    
    
    
    public function __construct(Twig\Environment $_6b67522fca36b32553cd09de29b97ff8, EventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        $this->twig = $_6b67522fca36b32553cd09de29b97ff8;
        $this->dispatcher = $_b497ce6f2af10f67516aed0ecf34d8cf;
    }
    public static function getSubscribedEvents()
    {
        return [KernelEvents::VIEW => [$GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_4c05b95d6bb119" . "1967ccfe58bffbb" . "d86"], -4]];
    }
    
    
    
    
    
    
    
    
    
    
    
    public function onKernelView(ViewEvent $event)
    {
        $_fd5a3a643834299cbdadfc3540ba0bcb = $event->getControllerResult();
        
        
        if (!$_fd5a3a643834299cbdadfc3540ba0bcb instanceof TwigResponse) {
            return;
        }
        
        
        $this->dispatchPreRenderEvent($_fd5a3a643834299cbdadfc3540ba0bcb);
        
        
        $this->updateControllerResultEvent($event, $_fd5a3a643834299cbdadfc3540ba0bcb);
    }
    
    
    
    
    
    
    
    
    protected function dispatchPreRenderEvent(TwigResponse $_fd5a3a643834299cbdadfc3540ba0bcb)
    {
        $event = new TwigPreRenderEvent($_fd5a3a643834299cbdadfc3540ba0bcb->getTemplate(), $_fd5a3a643834299cbdadfc3540ba0bcb->getArguments());
        $this->dispatcher->dispatch(TwigEvents::PRE_RENDER, $event);
        $_fd5a3a643834299cbdadfc3540ba0bcb->setTemplate($event->getTemplate());
        $_fd5a3a643834299cbdadfc3540ba0bcb->setArguments($event->getArguments());
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    protected function updateControllerResultEvent(ViewEvent $event, TwigResponse $_fd5a3a643834299cbdadfc3540ba0bcb)
    {
        if ($_fd5a3a643834299cbdadfc3540ba0bcb instanceof TwigTemplaterResponse) {
            
            
            
            $_edae18fae8c53743e7224eb1325ebb6b = new TemplaterCallResponse($GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_00b7858db26a1c1ca" . "db1466f573d5d80"], [$GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_6d3a1bbb0c16" . "fad009bf87b15" . "802998e"] => $_fd5a3a643834299cbdadfc3540ba0bcb->getTemplate(), $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_75ca9d21af5efc8ea1044388098af78" . "4"] => $_fd5a3a643834299cbdadfc3540ba0bcb->getArguments()], $_fd5a3a643834299cbdadfc3540ba0bcb->getPageTitle());
            $_edae18fae8c53743e7224eb1325ebb6b->http_status = $_fd5a3a643834299cbdadfc3540ba0bcb->getHttpStatus();
            $_edae18fae8c53743e7224eb1325ebb6b->http_headers = $_fd5a3a643834299cbdadfc3540ba0bcb->getHttpHeaders();
            $event->setControllerResult($_edae18fae8c53743e7224eb1325ebb6b);
        } else {
            
            
            $_fd5a3a643834299cbdadfc3540ba0bcb = new Response($this->twig->render($_fd5a3a643834299cbdadfc3540ba0bcb->getTemplate(), $_fd5a3a643834299cbdadfc3540ba0bcb->getArguments()), $_fd5a3a643834299cbdadfc3540ba0bcb->getHttpStatus(), $_fd5a3a643834299cbdadfc3540ba0bcb->getHttpHeaders());
            $event->setResponse($_fd5a3a643834299cbdadfc3540ba0bcb);
        }
    }
}
